@@ -4,11 +4,11 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Handler class for Google specific DKIM
-our $VERSION = '2.20200602.1'; # VERSION
+our $VERSION = '2.20200602.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
+use Mail::DKIM 0.54;
 use Mail::DKIM::DNS;
 use Mail::DKIM::Verifier;
-use Mail::DKIM;
 
 sub default_config {
     return {
@@ -92,11 +92,8 @@ sub eoh_callback {
         my $dkim;
         eval {
             $dkim = Mail::DKIM::Verifier->new();
-            # The following requires Mail::DKIM > 0.4
-            if ( $Mail::DKIM::VERSION >= 0.4 ) {
-                my $resolver = $self->get_object('resolver');
-                Mail::DKIM::DNS::resolver($resolver);
-            }
+            my $resolver = $self->get_object('resolver');
+            Mail::DKIM::DNS::resolver($resolver);
             $self->set_object('xgdkim', $dkim, 1);
         };
         if ( my $error = $@ ) {
@@ -309,7 +306,7 @@ Mail::Milter::Authentication::Handler::XGoogleDKIM - Handler class for Google sp
 
 =head1 VERSION
 
-version 2.20200602.1
+version 2.20200602.2
 
 =head1 DESCRIPTION
 
